@@ -56,6 +56,9 @@ import dialogs
 # default socket timeout to deal with unreachable screenshot site
 DEFAULT_SOCKET_TIMEOUT=4
 
+def apt_i18n(s):
+    return gettext.dgettext("libapt-pkg4.8", s)
+
 class AppDetailsView(WebkitWidget):
     """The view that shows the application details """
 
@@ -66,7 +69,8 @@ class AppDetailsView(WebkitWidget):
     # dependency types we are about
     # FIXME: we do not support warning about removal of stuff that is
     #        recommended because its not speced
-    DEPENDENCY_TYPES = ("PreDepends", "Depends") #, "Recommends")
+    DEPENDENCY_TYPES = (apt_i18n("PreDepends"), 
+                        apt_i18n("Depends")) 
     IMPORTANT_METAPACKAGES = ("ubuntu-desktop", "kubuntu-desktop")
 
     SCREENSHOT_THUMB_URL =  "http://screenshots.ubuntu.com/thumbnail-404/%s"
